# Youtube Autonomous Advanced Image Module

The image module, in the advanced version, capable of more things than the basic one (and needing more libraries).

Please, check the 'pyproject.toml' file to see the dependencies.